[Libreoffice-commits] core.git: Branch 'feature/gsoc14-draw-chained-text-boxes' - include/svx svx/source
matteocam
matteo.campanelli at gmail.com
Mon Jul 13 08:12:57 PDT 2015
include/svx/textchain.hxx | 7 +++++--
svx/source/svdraw/textchain.cxx | 9 +--------
2 files changed, 6 insertions(+), 10 deletions(-)
New commits:
commit afe335ac3bf0bcd79ee58699f132cf4ad7e5aefe
Author: matteocam <matteo.campanelli at gmail.com>
Date: Mon Jul 13 11:12:05 2015 -0400
Add IsPartOfLastParaInNextLink Property
Change-Id: I0410c4417bebb7ffb9cd162a1ecf3d5028f513fa
diff --git a/svx/source/svdraw/textchain.cxx b/svx/source/svdraw/textchain.cxx
index 36966bb..25b75ae 100644
--- a/svx/source/svdraw/textchain.cxx
+++ b/svx/source/svdraw/textchain.cxx
@@ -28,6 +28,7 @@ IMPL_CHAIN_PROP_INTERFACE(CursorEvent, CursorChainingEvent)
IMPL_CHAIN_PROP_INTERFACE(NilChainingEvent, bool)
IMPL_CHAIN_PROP_INTERFACE(PreChainingSel, ESelection)
IMPL_CHAIN_PROP_INTERFACE(PostChainingSel, ESelection)
+IMPL_CHAIN_PROP_INTERFACE(IsPartOfLastParaInNextLink, bool)
/* End Definition of Properties Interface */
@@ -59,14 +60,6 @@ SdrTextObj *TextChain::GetNextLink(SdrTextObj *) const
return NULL; // XXX: To be changed. It'd be a mess to implement now
}
-
-bool TextChain::GetLinksHaveMergeableFirstPara(SdrTextObj* /* pPrevLink */, SdrTextObj* /* pNextLink */)
-{
- // XXX
- return false;
-}
-
-
ImpChainLinkProperties *TextChain::GetLinkProperties(const SdrTextObj *pLink)
{
// if the guy does not already have properties in the map make them
More information about the Libreoffice-commits
mailing list
diff --git a/include/svx/textchain.hxx b/include/svx/textchain.hxx
index 6a70c8b..8d0ae47 100644
--- a/include/svx/textchain.hxx
+++ b/include/svx/textchain.hxx
@@ -117,6 +117,7 @@ class ImpChainLinkProperties
INIT_CHAIN_PROP(CursorEvent, CursorChainingEvent::NULL_EVENT)
INIT_CHAIN_PROP(PreChainingSel, ESelection(0,0,0,0));
INIT_CHAIN_PROP(PostChainingSel, ESelection(0,0,0,0));
+ INIT_CHAIN_PROP(IsPartOfLastParaInNextLink, false)
}
private:
@@ -125,6 +126,7 @@ class ImpChainLinkProperties
DECL_CHAIN_PROP(CursorEvent, CursorChainingEvent)
DECL_CHAIN_PROP(PreChainingSel, ESelection)
DECL_CHAIN_PROP(PostChainingSel, ESelection)
+ DECL_CHAIN_PROP(IsPartOfLastParaInNextLink, bool)
};
@@ -147,9 +149,10 @@ class TextChain {
DECL_CHAIN_PROP_INTERFACE(NilChainingEvent, bool)
DECL_CHAIN_PROP_INTERFACE(PreChainingSel, ESelection)
DECL_CHAIN_PROP_INTERFACE(PostChainingSel, ESelection)
+ // return whether a paragraph is split between this box and the next
+ DECL_CHAIN_PROP_INTERFACE(IsPartOfLastParaInNextLink, bool)
+
- // return whether a paragraph is split between the two links in the argument
- bool GetLinksHaveMergeableFirstPara(SdrTextObj *, SdrTextObj *);
protected:
LinkPropertiesMap maLinkPropertiesMap;